@@ -1,8 +1,8 @@
-import os
 import re
+from pathlib import Path
 
 from pipenv.project import Project
-from pipenv.utils import err
+from pipenv.utils import console, err
 from pipenv.utils.internet import is_valid_url
 from pipenv.vendor.click import (
     BadArgumentUsage,
@@ -10,7 +10,6 @@ from pipenv.vendor.click import (
     Group,
     Option,
     argument,
-    echo,
     make_pass_decorator,
     option,
 )
@@ -33,12 +32,7 @@ class PipenvGroup(DYMMixin, Group):
 
         def show_help(ctx, param, value):
             if value and not ctx.resilient_parsing:
-                if not ctx.invoked_subcommand:
-                    # legit main help
-                    echo(format_help(ctx.get_help()))
-                else:
-                    # legit sub-command help
-                    echo(ctx.get_help(), color=ctx.color)
+                console.print(format_help(ctx.get_help()))
                 ctx.exit()
 
         return Option(
@@ -466,8 +460,9 @@ def validate_python_path(ctx, param, value):
     # the path or an absolute path. To report errors as early as possible
     # we'll report absolute paths which do not exist:
     if isinstance(value, (str, bytes)):
-        if os.path.isabs(value) and not os.path.isfile(value):
-            raise BadParameter("Expected Python at path %s does not exist" % value)
+        path = Path(value)
+        if path.is_absolute() and not path.is_file():
+            raise BadParameter(f"Expected Python at path {value} does not exist")
     return value
 
 
@@ -479,7 +474,7 @@ def validate_bool_or_none(ctx, param, value):
 
 def validate_pypi_mirror(ctx, param, value):
     if value and not is_valid_url(value):
-        raise BadParameter("Invalid PyPI mirror URL: %s" % value)
+        raise BadParameter(f"Invalid PyPI mirror URL: {value}")
     return value
 
 
@@ -502,6 +497,7 @@ def skip_lock_option(f):
         default=False,
         expose_value=True,
         envvar="PIPENV_SKIP_LOCK",
+        help="Install from Pipfile bypassing lock mechanisms.",
         callback=callback,
         type=click_types.BOOL,
         show_envvar=True,
